const APPS = {
  // apps list start here
  // apps list end here
};

const ACTIONS = {
  // actions list start here
  // actions list end here
};

const COMPOSIO_VERSION = `0.5.39`;

module.exports = {
  APPS,
  ACTIONS,
  COMPOSIO_VERSION,
};
